Crate cfait

Crate cfait 

Modules

alarm_index
cache
cli
Shared command-line interface logic, like printing help.
client
color_utils
config
context
Application context abstraction for filesystem paths.
controller
Central logic controller for Task operations. This is the single source of truth for all business logic (create, update, delete, etc.). All UI layers (TUI, GUI, Mobile) must delegate actions to this controller to ensure consistent behavior for both online and offline operations.
help
Dynamic, localized help sections.
journal
model
storage
store
system
tui