pub struct RecurrenceEngine;Implementations
Sourceimpl RecurrenceEngine
impl RecurrenceEngine
Sourcepub fn next_occurrence(task: &Task) -> Option<Task>
pub fn next_occurrence(task: &Task) -> Option<Task>
Calculates the next occurrence of a task based on its RRULE. Returns a new Task instance for the next occurrence, or None if finished.